From b21dd894a728565df7cbdd41c063c00a21fb5975 Mon Sep 17 00:00:00 2001
From: James Coleman <jtc331@gmail.com>
Date: Mon, 30 Mar 2020 18:51:53 -0400
Subject: [PATCH v47 6/6] nPresortedCols

---
 src/backend/commands/explain.c             |  2 +-
 src/backend/executor/nodeIncrementalSort.c | 22 +++++++++++-----------
 src/backend/nodes/copyfuncs.c              |  2 +-
 src/backend/nodes/outfuncs.c               |  2 +-
 src/backend/nodes/readfuncs.c              |  2 +-
 src/backend/optimizer/plan/createplan.c    | 16 ++++++++--------
 src/backend/optimizer/util/pathnode.c      |  2 +-
 src/include/nodes/pathnodes.h              |  2 +-
 src/include/nodes/plannodes.h              |  2 +-
 9 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/src/backend/commands/explain.c b/src/backend/commands/explain.c
index cd2d81712f..02a81bebc3 100644
--- a/src/backend/commands/explain.c
+++ b/src/backend/commands/explain.c
@@ -2256,7 +2256,7 @@ show_incremental_sort_keys(IncrementalSortState *incrsortstate,
 	IncrementalSort *plan = (IncrementalSort *) incrsortstate->ss.ps.plan;
 
 	show_sort_group_keys((PlanState *) incrsortstate, "Sort Key",
-						 plan->sort.numCols, plan->presortedCols,
+						 plan->sort.numCols, plan->nPresortedCols,
 						 plan->sort.sortColIdx,
 						 plan->sort.sortOperators, plan->sort.collations,
 						 plan->sort.nullsFirst,
diff --git a/src/backend/executor/nodeIncrementalSort.c b/src/backend/executor/nodeIncrementalSort.c
index 6c683538ff..bcab7c054c 100644
--- a/src/backend/executor/nodeIncrementalSort.c
+++ b/src/backend/executor/nodeIncrementalSort.c
@@ -159,11 +159,11 @@ preparePresortedCols(IncrementalSortState *node)
 	IncrementalSort *plannode = castNode(IncrementalSort, node->ss.ps.plan);
 
 	node->presorted_keys =
-		(PresortedKeyData *) palloc(plannode->presortedCols *
+		(PresortedKeyData *) palloc(plannode->nPresortedCols *
 									sizeof(PresortedKeyData));
 
 	/* Pre-cache comparison functions for each pre-sorted key. */
-	for (int i = 0; i < plannode->presortedCols; i++)
+	for (int i = 0; i < plannode->nPresortedCols; i++)
 	{
 		Oid			equalityOp,
 					equalityFunc;
@@ -204,9 +204,9 @@ preparePresortedCols(IncrementalSortState *node)
 static bool
 isCurrentGroup(IncrementalSortState *node, TupleTableSlot *pivot, TupleTableSlot *tuple)
 {
-	int			presortedCols;
+	int			nPresortedCols;
 
-	presortedCols = castNode(IncrementalSort, node->ss.ps.plan)->presortedCols;
+	nPresortedCols = castNode(IncrementalSort, node->ss.ps.plan)->nPresortedCols;
 
 	/*
 	 * That the input is sorted by keys * (0, ... n) implies that the tail
@@ -214,7 +214,7 @@ isCurrentGroup(IncrementalSortState *node, TupleTableSlot *pivot, TupleTableSlot
 	 * from the last pre-sorted column to optimize for early detection of
 	 * inequality and minimizing the number of function calls..
 	 */
-	for (int i = presortedCols - 1; i >= 0; i--)
+	for (int i = nPresortedCols - 1; i >= 0; i--)
 	{
 		Datum		datumA,
 					datumB,
@@ -295,18 +295,18 @@ switchToPresortedPrefixMode(PlanState *pstate)
 	if (node->prefixsort_state == NULL)
 	{
 		Tuplesortstate *prefixsort_state;
-		int			presortedCols = plannode->presortedCols;
+		int			nPresortedCols = plannode->nPresortedCols;
 
 		/*
 		 * Optimize the sort by assuming the prefix columns are all equal and
 		 * thus we only need to sort by any remaining columns.
 		 */
 		prefixsort_state = tuplesort_begin_heap(tupDesc,
-												plannode->sort.numCols - presortedCols,
-												&(plannode->sort.sortColIdx[presortedCols]),
-												&(plannode->sort.sortOperators[presortedCols]),
-												&(plannode->sort.collations[presortedCols]),
-												&(plannode->sort.nullsFirst[presortedCols]),
+												plannode->sort.numCols - nPresortedCols,
+												&(plannode->sort.sortColIdx[nPresortedCols]),
+												&(plannode->sort.sortOperators[nPresortedCols]),
+												&(plannode->sort.collations[nPresortedCols]),
+												&(plannode->sort.nullsFirst[nPresortedCols]),
 												work_mem,
 												NULL,
 												false);
diff --git a/src/backend/nodes/copyfuncs.c b/src/backend/nodes/copyfuncs.c
index e21f48327d..f5977b0249 100644
--- a/src/backend/nodes/copyfuncs.c
+++ b/src/backend/nodes/copyfuncs.c
@@ -978,7 +978,7 @@ _copyIncrementalSort(const IncrementalSort *from)
 	/*
 	 * copy remainder of node
 	 */
-	COPY_SCALAR_FIELD(presortedCols);
+	COPY_SCALAR_FIELD(nPresortedCols);
 
 	return newnode;
 }
diff --git a/src/backend/nodes/outfuncs.c b/src/backend/nodes/outfuncs.c
index 6c83372c9f..dfe5fb4867 100644
--- a/src/backend/nodes/outfuncs.c
+++ b/src/backend/nodes/outfuncs.c
@@ -863,7 +863,7 @@ _outIncrementalSort(StringInfo str, const IncrementalSort *node)
 
 	_outSortInfo(str, (const Sort *) node);
 
-	WRITE_INT_FIELD(presortedCols);
+	WRITE_INT_FIELD(nPresortedCols);
 }
 
 static void
diff --git a/src/backend/nodes/readfuncs.c b/src/backend/nodes/readfuncs.c
index c5bbbf459e..2a2f39bf04 100644
--- a/src/backend/nodes/readfuncs.c
+++ b/src/backend/nodes/readfuncs.c
@@ -2190,7 +2190,7 @@ _readIncrementalSort(void)
 
 	ReadCommonSort(&local_node->sort);
 
-	READ_INT_FIELD(presortedCols);
+	READ_INT_FIELD(nPresortedCols);
 
 	READ_DONE();
 }
diff --git a/src/backend/optimizer/plan/createplan.c b/src/backend/optimizer/plan/createplan.c
index 1d7d4eb3e7..5be9135646 100644
--- a/src/backend/optimizer/plan/createplan.c
+++ b/src/backend/optimizer/plan/createplan.c
@@ -247,7 +247,7 @@ static Sort *make_sort(Plan *lefttree, int numCols,
 					   AttrNumber *sortColIdx, Oid *sortOperators,
 					   Oid *collations, bool *nullsFirst);
 static IncrementalSort *make_incrementalsort(Plan *lefttree,
-											 int numCols, int presortedCols,
+											 int numCols, int nPresortedCols,
 											 AttrNumber *sortColIdx, Oid *sortOperators,
 											 Oid *collations, bool *nullsFirst);
 static Plan *prepare_sort_from_pathkeys(Plan *lefttree, List *pathkeys,
@@ -265,7 +265,7 @@ static EquivalenceMember *find_ec_member_for_tle(EquivalenceClass *ec,
 static Sort *make_sort_from_pathkeys(Plan *lefttree, List *pathkeys,
 									 Relids relids);
 static IncrementalSort *make_incrementalsort_from_pathkeys(Plan *lefttree,
-														   List *pathkeys, Relids relids, int presortedCols);
+														   List *pathkeys, Relids relids, int nPresortedCols);
 static Sort *make_sort_from_groupcols(List *groupcls,
 									  AttrNumber *grpColIdx,
 									  Plan *lefttree);
@@ -2026,7 +2026,7 @@ create_incrementalsort_plan(PlannerInfo *root, IncrementalSortPath *best_path,
 											  best_path->spath.path.pathkeys,
 											  IS_OTHER_REL(best_path->spath.subpath->parent) ?
 											  best_path->spath.path.parent->relids : NULL,
-											  best_path->presortedCols);
+											  best_path->nPresortedCols);
 
 	copy_generic_path_info(&plan->sort.plan, (Path *) best_path);
 
@@ -5749,7 +5749,7 @@ make_sort(Plan *lefttree, int numCols,
  * nullsFirst arrays already.
  */
 static IncrementalSort *
-make_incrementalsort(Plan *lefttree, int numCols, int presortedCols,
+make_incrementalsort(Plan *lefttree, int numCols, int nPresortedCols,
 					 AttrNumber *sortColIdx, Oid *sortOperators,
 					 Oid *collations, bool *nullsFirst)
 {
@@ -5763,7 +5763,7 @@ make_incrementalsort(Plan *lefttree, int numCols, int presortedCols,
 	plan->qual = NIL;
 	plan->lefttree = lefttree;
 	plan->righttree = NULL;
-	node->presortedCols = presortedCols;
+	node->nPresortedCols = nPresortedCols;
 	node->sort.numCols = numCols;
 	node->sort.sortColIdx = sortColIdx;
 	node->sort.sortOperators = sortOperators;
@@ -6126,11 +6126,11 @@ make_sort_from_pathkeys(Plan *lefttree, List *pathkeys, Relids relids)
  *	  'lefttree' is the node which yields input tuples
  *	  'pathkeys' is the list of pathkeys by which the result is to be sorted
  *	  'relids' is the set of relations required by prepare_sort_from_pathkeys()
- *	  'presortedCols' is the number of presorted columns in input tuples
+ *	  'nPresortedCols' is the number of presorted columns in input tuples
  */
 static IncrementalSort *
 make_incrementalsort_from_pathkeys(Plan *lefttree, List *pathkeys,
-								   Relids relids, int presortedCols)
+								   Relids relids, int nPresortedCols)
 {
 	int			numsortkeys;
 	AttrNumber *sortColIdx;
@@ -6150,7 +6150,7 @@ make_incrementalsort_from_pathkeys(Plan *lefttree, List *pathkeys,
 										  &nullsFirst);
 
 	/* Now build the Sort node */
-	return make_incrementalsort(lefttree, numsortkeys, presortedCols,
+	return make_incrementalsort(lefttree, numsortkeys, nPresortedCols,
 								sortColIdx, sortOperators,
 								collations, nullsFirst);
 }
diff --git a/src/backend/optimizer/util/pathnode.c b/src/backend/optimizer/util/pathnode.c
index e20c055dea..5e752f64b9 100644
--- a/src/backend/optimizer/util/pathnode.c
+++ b/src/backend/optimizer/util/pathnode.c
@@ -2796,7 +2796,7 @@ create_incremental_sort_path(PlannerInfo *root,
 						  0.0,	/* XXX comparison_cost shouldn't be 0? */
 						  work_mem, limit_tuples);
 
-	sort->presortedCols = presorted_keys;
+	sort->nPresortedCols = presorted_keys;
 
 	return pathnode;
 }
diff --git a/src/include/nodes/pathnodes.h b/src/include/nodes/pathnodes.h
index 28d580dd3c..a7cf733951 100644
--- a/src/include/nodes/pathnodes.h
+++ b/src/include/nodes/pathnodes.h
@@ -1626,7 +1626,7 @@ typedef struct SortPath
 typedef struct IncrementalSortPath
 {
 	SortPath	spath;
-	int			presortedCols;	/* number of presorted columns */
+	int			nPresortedCols;	/* number of presorted columns */
 } IncrementalSortPath;
 
 /*
diff --git a/src/include/nodes/plannodes.h b/src/include/nodes/plannodes.h
index 136d794219..be8ef54a1e 100644
--- a/src/include/nodes/plannodes.h
+++ b/src/include/nodes/plannodes.h
@@ -781,7 +781,7 @@ typedef struct Sort
 typedef struct IncrementalSort
 {
 	Sort		sort;
-	int			presortedCols;	/* number of presorted columns */
+	int			nPresortedCols;	/* number of presorted columns */
 } IncrementalSort;
 
 /* ---------------
-- 
2.17.1

